#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509
version: 1.6.3
id: x509-1.6.3-ea92228b2bfea35f7dd001d2924d4ebd
key: x509_7d7izp22mhiF4F7b1SppwP
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X509 reader and writer
description:
    X509 reader and writer
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509
hidden-modules: Data.X509.Internal Data.X509.CertificateChain
                Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
                Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
                Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
                Data.X509.Signed
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/x509-1.6.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/x509-1.6.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/x509-1.6.3
hs-libraries: HSx509-1.6.3-7d7izp22mhiF4F7b1SppwP
depends:
    asn1-encoding-0.9.3-fec344bb54bb5da4bfe7deb0a3562b73
    asn1-parse-0.9.4-b064d91c5d9874d8c61bb184f001f6aa
    asn1-types-0.3.2-0a9b49f98bdd53624b82b3c86ed41efa
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptonite-0.15-52f487cbd51518538a9e7cbc4eddf82b
    hourglass-0.2.10-b11bcf654d7049575fb45d24076b832b
    memory-0.12-092368f288b8a5ed89de3a4f849c43f2
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pem-0.2.2-5f6df2ca3b7f68abc9010881cb82b5dd
haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html: /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
